@@ -4,20 +4,24 @@ from test.common import payload, pub_pem, pub_key
 from test import python_jwt as jwt
 from datetime import timedelta
 from pyvows import Vows, expect
+from jwcrypto.jwk import JWK
+from jwcrypto.common import base64url_encode
+
+pem_key = JWK(kty='oct', k=base64url_encode(pub_pem))
 
 @Vows.batch
 class PEMAsHMACKey(Vows.Context):
     """ setup tests """
     def topic(self):
         """ Generate token """
-        return jwt.generate_jwt(payload, pub_pem, 'HS256', timedelta(seconds=60))
+        return jwt.generate_jwt(payload, pem_key, 'HS256', timedelta(seconds=60))
 
     class VerifyTokenUsingPublicPEMNoAllowedAlgsSpecified(Vows.Context):
         """ Verify token, allowed algorithms not specified """
         @Vows.capture_error
         def topic(self, topic):
             """ Verify the token """
-            return jwt.verify_jwt(topic, pub_pem)
+            return jwt.verify_jwt(topic, pem_key)
 
         def token_should_not_verify(self, r):
             """ Should not verify """
@@ -29,7 +33,7 @@ class PEMAsHMACKey(Vows.Context):
         @Vows.capture_error
         def topic(self, topic):
             """ Verify the token """
-            return jwt.verify_jwt(topic, pub_pem, ['HS256'])
+            return jwt.verify_jwt(topic, pem_key, ['HS256'])
 
         def token_should_verify(self, r):
             """ Should verify """
@@ -40,7 +44,7 @@ class PEMAsHMACKey(Vows.Context):
         @Vows.capture_error
         def topic(self, topic):
             """ Verify the token """
-            return jwt.verify_jwt(topic, pub_pem, ['RS256'])
+            return jwt.verify_jwt(topic, pem_key, ['RS256'])
 
         def token_should_not_verify(self, r):
             """ Should not verify """
